BluetoothAdvertisingStateEvent class

BLE 广播状态事件。

Constructors

BluetoothAdvertisingStateEvent({required bool isAdvertising, int? errorCode, String? message})
创建广播状态事件。
const
BluetoothAdvertisingStateEvent.fromMap(Map<String, dynamic> map)
从原生 Map 创建广播状态事件。
factory

Properties

errorCode int?
Android 广播错误码,默认 null
final
hashCode int
The hash code for this object.
no setterinherited
isAdvertising bool
当前是否正在广播。
final
message String?
平台状态或错误消息,默认 null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited