BluetoothBondState enum

Android 配对/绑定状态。

iOS/macOS/Windows/Web 不公开可管理的配对状态;Linux/Android 可能产生该事件。

Inheritance
Available extensions

Values

none → const BluetoothBondState

未绑定。

bonding → const BluetoothBondState

正在绑定。

bonded → const BluetoothBondState

已绑定。

unknown → const BluetoothBondState

状态未知。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BluetoothBondState>
A constant List of the values in this enum, in order of their declaration.