BluetoothBondStateEvent class

Android 配对/绑定状态事件。

Constructors

BluetoothBondStateEvent({required String deviceId, required BluetoothBondState state})
创建绑定状态事件。
const
BluetoothBondStateEvent.fromMap(Map<String, dynamic> map)
从原生 Map 创建绑定状态事件。
factory

Properties

deviceId String
设备标识。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BluetoothBondState
绑定状态。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited