BluetoothCharacteristicValue class

GATT 特征值事件。

Constructors

BluetoothCharacteristicValue({required String deviceId, required String serviceUuid, required String characteristicUuid, required List<int> value})
创建特征值事件。
const
BluetoothCharacteristicValue.fromMap(Map<String, dynamic> map)
从原生 Map 创建特征值事件。
factory

Properties

characteristicUuid String
特征 UUID。
final
deviceId String
设备标识。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String
服务 UUID。
final
value List<int>
特征值字节数组。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited