BluetoothClassicConnectionEvent class

Classic Bluetooth 连接状态事件。

Constructors

BluetoothClassicConnectionEvent({required String deviceId, required BluetoothConnectionState state, String? error})
创建 Classic 连接状态事件。
const
BluetoothClassicConnectionEvent.fromMap(Map<String, dynamic> map)
从原生 Map 创建 Classic 连接状态事件。
factory

Properties

deviceId String
Classic 设备地址。
final
error String?
错误消息,默认 null
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BluetoothConnectionState
连接状态。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited