BluetoothDescriptorValue class

GATT 描述符值事件。

Constructors

BluetoothDescriptorValue({required String deviceId, required String serviceUuid, required String characteristicUuid, required String descriptorUuid, required List<int> value})
创建描述符值事件。
const
BluetoothDescriptorValue.fromMap(Map<String, dynamic> map)
从原生 Map 创建描述符值事件。
factory

Properties

characteristicUuid String
特征 UUID。
final
descriptorUuid String
描述符 UUID。
final
deviceId String
设备标识。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String
服务 UUID。
final
value List<int>
描述符值字节数组。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited