BluetoothGattServerRequest class

本地 GATT Server 请求/状态事件。

Constructors

BluetoothGattServerRequest({required String event, required String deviceId, String? serviceUuid, String? characteristicUuid, String? descriptorUuid, int? requestId, int offset = 0, List<int> value = const <int>[], bool preparedWrite = false, bool responseNeeded = false, Map<String, dynamic> raw = const <String, dynamic>{}})
创建 GATT Server 请求事件。
const
BluetoothGattServerRequest.fromMap(Map<String, dynamic> map)
从原生 Map 创建 GATT Server 请求事件。
factory

Properties

characteristicUuid String?
特征 UUID,默认 null
final
descriptorUuid String?
描述符 UUID,默认 null
final
deviceId String
中心设备标识。
final
event String
事件名称。
final
hashCode int
The hash code for this object.
no setterinherited
offset int
读写偏移,默认 0
final
preparedWrite bool
是否 prepared write,默认 false
final
raw Map<String, dynamic>
原生完整字段,默认空 Map。
final
requestId int?
Android GATT 请求 ID,默认 null
final
responseNeeded bool
是否需要响应,默认 false
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String?
服务 UUID,默认 null
final
value List<int>
请求或响应字节数组,默认空列表。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited