BluetoothMtuEvent class

MTU 更新事件。

Constructors

BluetoothMtuEvent({required String deviceId, required int mtu})
创建 MTU 事件。
const
BluetoothMtuEvent.fromMap(Map<String, dynamic> map)
从原生 Map 创建 MTU 事件。
factory

Properties

deviceId String
设备标识。
final
hashCode int
The hash code for this object.
no setterinherited
mtu int
MTU 或最大写入长度。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited