BluetoothPermissionStatus enum

蓝牙权限状态。

Android 会按具体权限返回多个键;iOS/macOS 通常只返回 bluetooth;Web 没有全局 预授权,不支持时返回 notApplicable,已授权过设备时返回 granted,否则返回 notDetermined

Inheritance
Available extensions

Values

unknown → const BluetoothPermissionStatus

状态未知,通常表示原生侧返回了未识别值。

notDetermined → const BluetoothPermissionStatus

尚未决定,常见于 iOS/macOS 首次触发 CoreBluetooth 授权前。

granted → const BluetoothPermissionStatus

已授权。

denied → const BluetoothPermissionStatus

已拒绝。

restricted → const BluetoothPermissionStatus

被系统策略限制,例如家长控制或企业策略。

permanentlyDenied → const BluetoothPermissionStatus

永久拒绝,需要引导用户到系统设置中开启。

notApplicable → const BluetoothPermissionStatus

当前平台或系统版本不需要/不适用该权限。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BluetoothPermissionStatus>
A constant List of the values in this enum, in order of their declaration.