BluetoothPhy enum

BLE PHY 类型。

Android 8.0+ 可读取/设置;iOS/macOS/Linux/Windows/Web 通常返回 unknown

Inheritance
Available extensions

Values

le1m → const BluetoothPhy

LE 1M PHY,兼容性最好,默认回退推荐。

le2m → const BluetoothPhy

LE 2M PHY,短距离高吞吐推荐,需硬件支持。

leCoded → const BluetoothPhy

LE Coded PHY,长距离低速场景使用,需硬件支持。

unknown → const BluetoothPhy

未知或当前平台不支持读取。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BluetoothPhy>
A constant List of the values in this enum, in order of their declaration.