BluetoothScanMode enum

扫描模式。

ble 为默认值和跨平台推荐值;classicdual 的 Classic 部分仅 Android 有意义, iOS/macOS/Linux/Windows/Web 不支持 Classic Bluetooth。Linux/Windows/Web 的 dual 仅使用 BLE 部分。

Inheritance
Available extensions

Values

ble → const BluetoothScanMode

仅扫描 BLE 设备,默认值,跨平台推荐。

classic → const BluetoothScanMode

仅扫描 Android Classic Bluetooth 设备;其它平台通常返回不支持。

dual → const BluetoothScanMode

Android 上同时扫描 BLE 与 Classic 设备;Linux/Windows/Web 仅使用 BLE 部分;耗电和事件量更高。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BluetoothScanMode>
A constant List of the values in this enum, in order of their declaration.