BluetoothAdvertisingMode enum
BLE 广播模式。
默认推荐 balanced。Android 会应用这些设置;iOS/macOS 当前忽略广播设置。
Values
- lowPower → const BluetoothAdvertisingMode
-
低功耗广播,适合长时间后台或低频发现。
- balanced → const BluetoothAdvertisingMode
-
均衡广播,默认值,常规推荐。
- lowLatency → const BluetoothAdvertisingMode
-
低延迟高频广播,适合短时间快速发现,耗电更高。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BluetoothAdvertisingMode> - A constant List of the values in this enum, in order of their declaration.