BluetoothAdvertisingSettings class
BLE 广播设置。
Constructors
- BluetoothAdvertisingSettings({BluetoothAdvertisingMode mode = BluetoothAdvertisingMode.balanced, BluetoothTxPowerLevel txPowerLevel = BluetoothTxPowerLevel.medium, bool connectable = true, Duration? timeout})
-
创建广播设置。
const
Properties
- connectable → bool
-
是否可连接,默认
true。final - hashCode → int
-
The hash code for this object.
no setterinherited
- mode → BluetoothAdvertisingMode
-
广播模式,默认 BluetoothAdvertisingMode.balanced。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
广播超时,默认
null表示不自动停止。final - txPowerLevel → BluetoothTxPowerLevel
-
发射功率,默认 BluetoothTxPowerLevel.medium。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - 转为可传给原生端的 Map。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited