BluetoothGattDescriptor class
GATT 描述符。
Constructors
-
BluetoothGattDescriptor({required String uuid, String? characteristicUuid, List<
int> value = const <int>[], Map<String, dynamic> raw = const <String, dynamic>{}}) -
创建 GATT 描述符。
const
-
BluetoothGattDescriptor.fromMap(Map<
String, dynamic> map) -
从原生 Map 创建 GATT 描述符。
factory
Properties
- characteristicUuid → String?
-
所属特征 UUID,默认
null。final - hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ Map<
String, dynamic> -
原生完整字段,默认空 Map。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
描述符 UUID。
final
-
value
→ List<
int> -
描述符值,默认空字节数组。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - 转为可传给原生端的 Map。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited