BluetoothPhyEvent class
BLE PHY 事件。
Constructors
- BluetoothPhyEvent({required String deviceId, required BluetoothPhy txPhy, required BluetoothPhy rxPhy, int? status})
-
创建 PHY 事件。
const
-
BluetoothPhyEvent.fromMap(Map<
String, dynamic> map) -
从原生 Map 创建 PHY 事件。
factory
Properties
- deviceId → String
-
设备标识。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- rxPhy → BluetoothPhy
-
接收方向 PHY。
final
- status → int?
-
平台原生状态码,默认
null。final - txPhy → BluetoothPhy
-
发送方向 PHY。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited