BluetoothScanResult class
扫描结果。
Constructors
-
BluetoothScanResult({required BluetoothDevice device, required int rssi, String? localName, List<
String> serviceUuids = const <String>[], Map<int, List< manufacturerData = const <int, List<int>>{}, Map<int> >String, List< serviceData = const <String, List<int>>{}, int? txPowerLevel, bool? isConnectable, Map<int> >String, dynamic> raw = const <String, dynamic>{}}) -
创建扫描结果。
const
-
BluetoothScanResult.fromMap(Map<
String, dynamic> map) -
从原生 Map 创建扫描结果。
factory
Properties
- device → BluetoothDevice
-
扫描到的设备。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnectable → bool?
-
是否可连接,默认
null。final - localName → String?
-
广播本地名称,默认
null。final -
manufacturerData
→ Map<
int, List< int> > -
厂商数据,默认空 Map;key 为蓝牙 SIG Company ID。
final
-
raw
→ Map<
String, dynamic> -
原生完整字段,默认空 Map。
final
- rssi → int
-
信号强度 dBm。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceData
→ Map<
String, List< int> > -
服务数据,默认空 Map;key 为服务 UUID。
final
-
serviceUuids
→ List<
String> -
广播服务 UUID 列表,默认空列表。
final
- txPowerLevel → int?
-
广播发射功率,默认
null。final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
返回便于日志输出的扫描结果摘要。
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited